# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/iv_svi_parameters_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.sdk/stream/iv_svi_parameters_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcf\x03\n\x1fStreamIvSviParametersResponseV1\x12\x33\n\x0f\x64\x61ta_start_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rdata_end_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65xpiry\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\texchanges\x18\x04 \x03(\t\x12\x0c\n\x04\x62\x61se\x18\x05 \x01(\t\x12\r\n\x05quote\x18\x06 \x01(\t\x12\x16\n\x0etime_to_expiry\x18\x07 \x01(\t\x12\x1c\n\x14\x61tm_implied_variance\x18\x08 \x01(\t\x12\x10\n\x08\x61tm_skew\x18\t \x01(\t\x12\x12\n\nleft_slope\x18\n \x01(\t\x12\x13\n\x0bright_slope\x18\x0b \x01(\t\x12\x1c\n\x14min_implied_variance\x18\x0c \x01(\t\x12\x14\n\x0c\x63urrent_spot\x18\r \x01(\t\x12\x15\n\rinterest_rate\x18\x0e \x01(\t\x12,\n\x08ts_event\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xa4\x01\n)com.kaiko.sdk.stream.iv_svi_parameters_v1P\x01ZRgithub.com/kaikodata/kaiko-go-sdk/stream/iv_svi_parameters_v1;iv_svi_parameters_v1\xaa\x02 KaikoSdk.Stream.IvSviParameterV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.iv_svi_parameters_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.kaiko.sdk.stream.iv_svi_parameters_v1P\001ZRgithub.com/kaikodata/kaiko-go-sdk/stream/iv_svi_parameters_v1;iv_svi_parameters_v1\252\002 KaikoSdk.Stream.IvSviParameterV1'
  _globals['_STREAMIVSVIPARAMETERSRESPONSEV1']._serialized_start=94
  _globals['_STREAMIVSVIPARAMETERSRESPONSEV1']._serialized_end=557
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_v1/commodity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#sdk/stream/index_v1/commodity.proto\x12\x08kaikosdk*P\n\x14StreamIndexCommodity\x12\x0f\n\x0bSIC_UNKNOWN\x10\x00\x12\x11\n\rSIC_REAL_TIME\x10\x01\x12\x14\n\x10SIC_DAILY_FIXING\x10\x02\x42w\n\x1d\x63om.kaiko.sdk.stream.index_v1P\x01Z:github.com/kaikodata/kaiko-go-sdk/stream/index_v1;index_v1\xaa\x02\x17KaikoSdk.Stream.IndexV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.index_v1.commodity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.kaiko.sdk.stream.index_v1P\001Z:github.com/kaikodata/kaiko-go-sdk/stream/index_v1;index_v1\252\002\027KaikoSdk.Stream.IndexV1'
  _globals['_STREAMINDEXCOMMODITY']._serialized_start=49
  _globals['_STREAMINDEXCOMMODITY']._serialized_end=129
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/derivatives_instrument_metrics_v1/commodity_kind.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAsdk/stream/derivatives_instrument_metrics_v1/commodity_kind.proto\x12\x08kaikosdk*`\n*StreamDerivativesInstrumentCommodityKindV1\x12\x11\n\rSDICK_UNKNOWN\x10\x00\x12\x0f\n\x0bSDICK_PRICE\x10\x01\x12\x0e\n\nSDICK_RISK\x10\x02\x42\xd9\x01\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\x01Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\xaa\x02.KaikoSdk.Stream.DerivativesInstrumentMetricsV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.derivatives_instrument_metrics_v1.commodity_kind_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\001Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\252\002.KaikoSdk.Stream.DerivativesInstrumentMetricsV1'
  _globals['_STREAMDERIVATIVESINSTRUMENTCOMMODITYKINDV1']._serialized_start=79
  _globals['_STREAMDERIVATIVESINSTRUMENTCOMMODITYKINDV1']._serialized_end=175
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregated_quote_v2/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-sdk/stream/aggregated_quote_v2/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\";\n\x1aStreamAggregatedQuoteValue\x12\r\n\x05price\x18\x01 \x01(\t\x12\x0e\n\x06volume\x18\x02 \x01(\t\"\xf7\x02\n\x1fStreamAggregatedQuoteResponseV2\x12\x11\n\taggregate\x18\x01 \x01(\t\x12\x18\n\x10instrument_class\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12G\n\nevent_type\x18\x04 \x01(\x0e\x32\x33.kaikosdk.StreamAggregatedQuoteResponseV2.EventType\x12,\n\x08ts_event\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x06vetted\x18\x06 \x01(\x0b\x32$.kaikosdk.StreamAggregatedQuoteValue\x12\x36\n\x08unvetted\x18\x07 \x01(\x0b\x32$.kaikosdk.StreamAggregatedQuoteValue\"4\n\tEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x42\x45ST_ASK\x10\x01\x12\x0c\n\x08\x42\x45ST_BID\x10\x02\x42\xa2\x01\n(com.kaiko.sdk.stream.aggregated_quote_v2P\x01ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregated_quote_v2;aggregated_quote_v2\xaa\x02!KaikoSdk.Stream.AggregatedQuoteV2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregated_quote_v2.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.kaiko.sdk.stream.aggregated_quote_v2P\001ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregated_quote_v2;aggregated_quote_v2\252\002!KaikoSdk.Stream.AggregatedQuoteV2'
  _globals['_STREAMAGGREGATEDQUOTEVALUE']._serialized_start=92
  _globals['_STREAMAGGREGATEDQUOTEVALUE']._serialized_end=151
  _globals['_STREAMAGGREGATEDQUOTERESPONSEV2']._serialized_start=154
  _globals['_STREAMAGGREGATEDQUOTERESPONSEV2']._serialized_end=529
  _globals['_STREAMAGGREGATEDQUOTERESPONSEV2_EVENTTYPE']._serialized_start=477
  _globals['_STREAMAGGREGATEDQUOTERESPONSEV2_EVENTTYPE']._serialized_end=529
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import wrappers_pb2 as sdk_dot_core_dot_wrappers__pb2
from kaikosdk.stream.market_update_v1 import commodity_pb2 as sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*sdk/stream/market_update_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17sdk/core/wrappers.proto\x1a+sdk/stream/market_update_v1/commodity.proto\"\x83\x08\n\x1cStreamMarketUpdateResponseV1\x12\x38\n\tcommodity\x18\x01 \x01(\x0e\x32%.kaikosdk.StreamMarketUpdateCommodity\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\x12\x13\n\x0bsequence_id\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\x01\x12-\n\x0bts_exchange\x18\t \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12/\n\rts_collection\x18\n \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12,\n\x08ts_event\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12R\n\x0bupdate_type\x18\x0c \x01(\x0e\x32=.kaikosdk.StreamMarketUpdateResponseV1.StreamMarketUpdateType\x12\x41\n\x08snapshot\x18\r \x01(\x0b\x32/.kaikosdk.StreamMarketUpdateResponseV1.Snapshot\x12_\n\x15\x61\x64\x64itional_properties\x18\x0e \x03(\x0b\x32@.kaikosdk.StreamMarketUpdateResponseV1.AdditionalPropertiesEntry\x1a\xbc\x01\n\x08Snapshot\x12\x43\n\x04\x61sks\x18\x01 \x03(\x0b\x32\x35.kaikosdk.StreamMarketUpdateResponseV1.Snapshot.Order\x12\x43\n\x04\x62ids\x18\x02 \x03(\x0b\x32\x35.kaikosdk.StreamMarketUpdateResponseV1.Snapshot.Order\x1a&\n\x05Order\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x01\x12\r\n\x05price\x18\x02 \x01(\x01\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x01\n\x16StreamMarketUpdateType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tTRADE_BUY\x10\x01\x12\x0e\n\nTRADE_SELL\x10\x02\x12\x11\n\rTRADE_UNKNOWN\x10\t\x12\x0c\n\x08\x42\x45ST_ASK\x10\x03\x12\x0c\n\x08\x42\x45ST_BID\x10\x04\x12\x0f\n\x0bUPDATED_ASK\x10\x05\x12\x0f\n\x0bUPDATED_BID\x10\x06\x12\x0c\n\x08SNAPSHOT\x10\x07\x12\x12\n\x0e\x46ORCE_SNAPSHOT\x10\x08\x42\x96\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.market_update_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1'
  _STREAMMARKETUPDATERESPONSEV1_ADDITIONALPROPERTIESENTRY._options = None
  _STREAMMARKETUPDATERESPONSEV1_ADDITIONALPROPERTIESENTRY._serialized_options = b'8\001'
  _globals['_STREAMMARKETUPDATERESPONSEV1']._serialized_start=160
  _globals['_STREAMMARKETUPDATERESPONSEV1']._serialized_end=1187
  _globals['_STREAMMARKETUPDATERESPONSEV1_SNAPSHOT']._serialized_start=752
  _globals['_STREAMMARKETUPDATERESPONSEV1_SNAPSHOT']._serialized_end=940
  _globals['_STREAMMARKETUPDATERESPONSEV1_SNAPSHOT_ORDER']._serialized_start=902
  _globals['_STREAMMARKETUPDATERESPONSEV1_SNAPSHOT_ORDER']._serialized_end=940
  _globals['_STREAMMARKETUPDATERESPONSEV1_ADDITIONALPROPERTIESENTRY']._serialized_start=942
  _globals['_STREAMMARKETUPDATERESPONSEV1_ADDITIONALPROPERTIESENTRY']._serialized_end=1001
  _globals['_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE']._serialized_start=1004
  _globals['_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE']._serialized_end=1187
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/sdk.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.stream.aggregated_price_v1 import request_pb2 as sdk_dot_stream_dot_aggregated__price__v1_dot_request__pb2
from kaikosdk.stream.aggregated_price_v1 import response_pb2 as sdk_dot_stream_dot_aggregated__price__v1_dot_response__pb2
from kaikosdk.stream.aggregated_quote_v2 import request_pb2 as sdk_dot_stream_dot_aggregated__quote__v2_dot_request__pb2
from kaikosdk.stream.aggregated_quote_v2 import response_pb2 as sdk_dot_stream_dot_aggregated__quote__v2_dot_response__pb2
from kaikosdk.stream.aggregates_direct_exchange_rate_v2 import request_pb2 as sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_request__pb2
from kaikosdk.stream.aggregates_direct_exchange_rate_v2 import response_pb2 as sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_response__pb2
from kaikosdk.stream.aggregates_ohlcv_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_request__pb2
from kaikosdk.stream.aggregates_ohlcv_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_response__pb2
from kaikosdk.stream.aggregates_spot_exchange_rate_v2 import request_pb2 as sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_request__pb2
from kaikosdk.stream.aggregates_spot_exchange_rate_v2 import response_pb2 as sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_response__pb2
from kaikosdk.stream.aggregates_vwap_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__vwap__v1_dot_request__pb2
from kaikosdk.stream.aggregates_vwap_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__vwap__v1_dot_response__pb2
from kaikosdk.stream.derivatives_instrument_metrics_v1 import request_pb2 as sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_request__pb2
from kaikosdk.stream.derivatives_instrument_metrics_v1 import response_pb2 as sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_response__pb2
from kaikosdk.stream.exotic_indices_v1 import request_pb2 as sdk_dot_stream_dot_exotic__indices__v1_dot_request__pb2
from kaikosdk.stream.exotic_indices_v1 import response_pb2 as sdk_dot_stream_dot_exotic__indices__v1_dot_response__pb2
from kaikosdk.stream.index_forex_rate_v1 import request_pb2 as sdk_dot_stream_dot_index__forex__rate__v1_dot_request__pb2
from kaikosdk.stream.index_forex_rate_v1 import response_pb2 as sdk_dot_stream_dot_index__forex__rate__v1_dot_response__pb2
from kaikosdk.stream.index_multi_assets_v1 import request_pb2 as sdk_dot_stream_dot_index__multi__assets__v1_dot_request__pb2
from kaikosdk.stream.index_multi_assets_v1 import response_pb2 as sdk_dot_stream_dot_index__multi__assets__v1_dot_response__pb2
from kaikosdk.stream.index_v1 import request_pb2 as sdk_dot_stream_dot_index__v1_dot_request__pb2
from kaikosdk.stream.index_v1 import response_pb2 as sdk_dot_stream_dot_index__v1_dot_response__pb2
from kaikosdk.stream.iv_svi_parameters_v1 import request_pb2 as sdk_dot_stream_dot_iv__svi__parameters__v1_dot_request__pb2
from kaikosdk.stream.iv_svi_parameters_v1 import response_pb2 as sdk_dot_stream_dot_iv__svi__parameters__v1_dot_response__pb2
from kaikosdk.stream.market_update_v1 import request_pb2 as sdk_dot_stream_dot_market__update__v1_dot_request__pb2
from kaikosdk.stream.market_update_v1 import response_pb2 as sdk_dot_stream_dot_market__update__v1_dot_response__pb2
from kaikosdk.stream.trades_v1 import request_pb2 as sdk_dot_stream_dot_trades__v1_dot_request__pb2
from kaikosdk.stream.trades_v1 import response_pb2 as sdk_dot_stream_dot_trades__v1_dot_response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsdk/sdk.proto\x12\x08kaikosdk\x1a,sdk/stream/aggregated_price_v1/request.proto\x1a-sdk/stream/aggregated_price_v1/response.proto\x1a,sdk/stream/aggregated_quote_v2/request.proto\x1a-sdk/stream/aggregated_quote_v2/response.proto\x1a;sdk/stream/aggregates_direct_exchange_rate_v2/request.proto\x1a<sdk/stream/aggregates_direct_exchange_rate_v2/response.proto\x1a,sdk/stream/aggregates_ohlcv_v1/request.proto\x1a-sdk/stream/aggregates_ohlcv_v1/response.proto\x1a\x39sdk/stream/aggregates_spot_exchange_rate_v2/request.proto\x1a:sdk/stream/aggregates_spot_exchange_rate_v2/response.proto\x1a+sdk/stream/aggregates_vwap_v1/request.proto\x1a,sdk/stream/aggregates_vwap_v1/response.proto\x1a:sdk/stream/derivatives_instrument_metrics_v1/request.proto\x1a;sdk/stream/derivatives_instrument_metrics_v1/response.proto\x1a*sdk/stream/exotic_indices_v1/request.proto\x1a+sdk/stream/exotic_indices_v1/response.proto\x1a,sdk/stream/index_forex_rate_v1/request.proto\x1a-sdk/stream/index_forex_rate_v1/response.proto\x1a.sdk/stream/index_multi_assets_v1/request.proto\x1a/sdk/stream/index_multi_assets_v1/response.proto\x1a!sdk/stream/index_v1/request.proto\x1a\"sdk/stream/index_v1/response.proto\x1a-sdk/stream/iv_svi_parameters_v1/request.proto\x1a.sdk/stream/iv_svi_parameters_v1/response.proto\x1a)sdk/stream/market_update_v1/request.proto\x1a*sdk/stream/market_update_v1/response.proto\x1a\"sdk/stream/trades_v1/request.proto\x1a#sdk/stream/trades_v1/response.proto2\x86\x01\n\x1eStreamAggregatedQuoteServiceV2\x12\x64\n\tSubscribe\x12(.kaikosdk.StreamAggregatedQuoteRequestV2\x1a).kaikosdk.StreamAggregatedQuoteResponseV2\"\x00\x30\x01\x32\x89\x01\n\x1eStreamAggregatedPriceServiceV1\x12g\n\tSubscribe\x12(.kaikosdk.StreamAggregatedPriceRequestV1\x1a).kaikosdk.StreamAggregatedPriceResponseV1\"\x03\x88\x02\x01\x30\x01\x32\x86\x01\n\x1eStreamAggregatesOHLCVServiceV1\x12\x64\n\tSubscribe\x12(.kaikosdk.StreamAggregatesOHLCVRequestV1\x1a).kaikosdk.StreamAggregatesOHLCVResponseV1\"\x00\x30\x01\x32k\n\x15StreamTradesServiceV1\x12R\n\tSubscribe\x12\x1f.kaikosdk.StreamTradesRequestV1\x1a .kaikosdk.StreamTradesResponseV1\"\x00\x30\x01\x32\x83\x01\n\x1dStreamAggregatesVWAPServiceV1\x12\x62\n\tSubscribe\x12\'.kaikosdk.StreamAggregatesVWAPRequestV1\x1a(.kaikosdk.StreamAggregatesVWAPResponseV1\"\x00\x30\x01\x32v\n\x14StreamIndexServiceV1\x12^\n\tSubscribe\x12%.kaikosdk.StreamIndexServiceRequestV1\x1a&.kaikosdk.StreamIndexServiceResponseV1\"\x00\x30\x01\x32\x97\x01\n\x1fStreamIndexMultiAssetsServiceV1\x12t\n\tSubscribe\x12\x30.kaikosdk.StreamIndexMultiAssetsServiceRequestV1\x1a\x31.kaikosdk.StreamIndexMultiAssetsServiceResponseV1\"\x00\x30\x01\x32}\n\x1bStreamMarketUpdateServiceV1\x12^\n\tSubscribe\x12%.kaikosdk.StreamMarketUpdateRequestV1\x1a&.kaikosdk.StreamMarketUpdateResponseV1\"\x00\x30\x01\x32\xad\x01\n+StreamAggregatesSpotExchangeRateV2ServiceV1\x12~\n\tSubscribe\x12\x35.kaikosdk.StreamAggregatesSpotExchangeRateV2RequestV1\x1a\x36.kaikosdk.StreamAggregatesSpotExchangeRateV2ResponseV1\"\x00\x30\x01\x32\xb8\x01\n1StreamAggregatesSpotDirectExchangeRateV2ServiceV1\x12\x82\x01\n\tSubscribe\x12\x37.kaikosdk.StreamAggregatesDirectExchangeRateV2RequestV1\x1a\x38.kaikosdk.StreamAggregatesDirectExchangeRateV2ResponseV1\"\x00\x30\x01\x32\x91\x01\n\x1dStreamIndexForexRateServiceV1\x12p\n\tSubscribe\x12..kaikosdk.StreamIndexForexRateServiceRequestV1\x1a/.kaikosdk.StreamIndexForexRateServiceResponseV1\"\x00\x30\x01\x32\xad\x01\n+StreamDerivativesInstrumentMetricsServiceV1\x12~\n\tSubscribe\x12\x35.kaikosdk.StreamDerivativesInstrumentMetricsRequestV1\x1a\x36.kaikosdk.StreamDerivativesInstrumentMetricsResponseV1\"\x00\x30\x01\x32\x86\x01\n\x1eStreamIvSviParametersServiceV1\x12\x64\n\tSubscribe\x12(.kaikosdk.StreamIvSviParametersRequestV1\x1a).kaikosdk.StreamIvSviParametersResponseV1\"\x00\x30\x01\x32\x8e\x01\n\x1cStreamExoticIndicesServiceV1\x12n\n\tSubscribe\x12-.kaikosdk.StreamExoticIndicesServiceRequestV1\x1a..kaikosdk.StreamExoticIndicesServiceResponseV1\"\x00\x30\x01\x42R\n\rcom.kaiko.sdkB\x08SdkProtoP\x01Z*github.com/kaikodata/kaiko-go-sdk;kaikosdk\xaa\x02\x08KaikoSdkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.sdk_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.kaiko.sdkB\010SdkProtoP\001Z*github.com/kaikodata/kaiko-go-sdk;kaikosdk\252\002\010KaikoSdk'
  _STREAMAGGREGATEDPRICESERVICEV1.methods_by_name['Subscribe']._options = None
  _STREAMAGGREGATEDPRICESERVICEV1.methods_by_name['Subscribe']._serialized_options = b'\210\002\001'
  _globals['_STREAMAGGREGATEDQUOTESERVICEV2']._serialized_start=1366
  _globals['_STREAMAGGREGATEDQUOTESERVICEV2']._serialized_end=1500
  _globals['_STREAMAGGREGATEDPRICESERVICEV1']._serialized_start=1503
  _globals['_STREAMAGGREGATEDPRICESERVICEV1']._serialized_end=1640
  _globals['_STREAMAGGREGATESOHLCVSERVICEV1']._serialized_start=1643
  _globals['_STREAMAGGREGATESOHLCVSERVICEV1']._serialized_end=1777
  _globals['_STREAMTRADESSERVICEV1']._serialized_start=1779
  _globals['_STREAMTRADESSERVICEV1']._serialized_end=1886
  _globals['_STREAMAGGREGATESVWAPSERVICEV1']._serialized_start=1889
  _globals['_STREAMAGGREGATESVWAPSERVICEV1']._serialized_end=2020
  _globals['_STREAMINDEXSERVICEV1']._serialized_start=2022
  _globals['_STREAMINDEXSERVICEV1']._serialized_end=2140
  _globals['_STREAMINDEXMULTIASSETSSERVICEV1']._serialized_start=2143
  _globals['_STREAMINDEXMULTIASSETSSERVICEV1']._serialized_end=2294
  _globals['_STREAMMARKETUPDATESERVICEV1']._serialized_start=2296
  _globals['_STREAMMARKETUPDATESERVICEV1']._serialized_end=2421
  _globals['_STREAMAGGREGATESSPOTEXCHANGERATEV2SERVICEV1']._serialized_start=2424
  _globals['_STREAMAGGREGATESSPOTEXCHANGERATEV2SERVICEV1']._serialized_end=2597
  _globals['_STREAMAGGREGATESSPOTDIRECTEXCHANGERATEV2SERVICEV1']._serialized_start=2600
  _globals['_STREAMAGGREGATESSPOTDIRECTEXCHANGERATEV2SERVICEV1']._serialized_end=2784
  _globals['_STREAMINDEXFOREXRATESERVICEV1']._serialized_start=2787
  _globals['_STREAMINDEXFOREXRATESERVICEV1']._serialized_end=2932
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSSERVICEV1']._serialized_start=2935
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSSERVICEV1']._serialized_end=3108
  _globals['_STREAMIVSVIPARAMETERSSERVICEV1']._serialized_start=3111
  _globals['_STREAMIVSVIPARAMETERSSERVICEV1']._serialized_end=3245
  _globals['_STREAMEXOTICINDICESSERVICEV1']._serialized_start=3248
  _globals['_STREAMEXOTICINDICESSERVICEV1']._serialized_end=3390
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sdk/stream/index_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1csdk/core/data_interval.proto\x1a#sdk/stream/index_v1/commodity.proto\"\x83\x01\n$StreamIndexServiceResponsePercentage\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x38\n\x05pairs\x18\x03 \x03(\x0b\x32).kaikosdk.StreamIndexServiceResponsePairs\"\x85\x01\n\x1fStreamIndexServiceResponsePairs\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x44\n\x0binstruments\x18\x03 \x03(\x0b\x32/.kaikosdk.StreamIndexServiceResponseInstruments\"\x7f\n!StreamIndexServiceUnderlyingTrade\x12\x0e\n\x06volume\x18\x01 \x01(\x01\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12,\n\x08\x64\x61tetime\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xaf\x01\n%StreamIndexServiceResponseInstruments\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x01\x12\r\n\x05\x63ount\x18\x04 \x01(\x04\x12\x45\n\x10underlying_trade\x18\x05 \x01(\x0b\x32+.kaikosdk.StreamIndexServiceUnderlyingTrade\"D\n#StreamIndexServiceResponseBaseAsset\x12\r\n\x05\x61sset\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\"\xad\x03\n\x1cStreamIndexServiceResponseV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x31\n\tcommodity\x18\x02 \x01(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\r\n\x05quote\x18\x04 \x01(\t\x12<\n\x05\x62\x61ses\x18\x05 \x03(\x0b\x32-.kaikosdk.StreamIndexServiceResponseBaseAsset\x12\x11\n\texchanges\x18\x06 \x03(\t\x12\x43\n\x0bpercentages\x18\x07 \x03(\x0b\x32..kaikosdk.StreamIndexServiceResponsePercentage\x12,\n\x08ts_event\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bsequence_id\x18\t \x01(\t\x12\x34\n\x10last_ingest_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampBw\n\x1d\x63om.kaiko.sdk.stream.index_v1P\x01Z:github.com/kaikodata/kaiko-go-sdk/stream/index_v1;index_v1\xaa\x02\x17KaikoSdk.Stream.IndexV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.index_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.kaiko.sdk.stream.index_v1P\001Z:github.com/kaikodata/kaiko-go-sdk/stream/index_v1;index_v1\252\002\027KaikoSdk.Stream.IndexV1'
  _globals['_STREAMINDEXSERVICERESPONSEPERCENTAGE']._serialized_start=149
  _globals['_STREAMINDEXSERVICERESPONSEPERCENTAGE']._serialized_end=280
  _globals['_STREAMINDEXSERVICERESPONSEPAIRS']._serialized_start=283
  _globals['_STREAMINDEXSERVICERESPONSEPAIRS']._serialized_end=416
  _globals['_STREAMINDEXSERVICEUNDERLYINGTRADE']._serialized_start=418
  _globals['_STREAMINDEXSERVICEUNDERLYINGTRADE']._serialized_end=545
  _globals['_STREAMINDEXSERVICERESPONSEINSTRUMENTS']._serialized_start=548
  _globals['_STREAMINDEXSERVICERESPONSEINSTRUMENTS']._serialized_end=723
  _globals['_STREAMINDEXSERVICERESPONSEBASEASSET']._serialized_start=725
  _globals['_STREAMINDEXSERVICERESPONSEBASEASSET']._serialized_end=793
  _globals['_STREAMINDEXSERVICERESPONSEV1']._serialized_start=796
  _globals['_STREAMINDEXSERVICERESPONSEV1']._serialized_end=1225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_direct_exchange_rate_v2/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import assets_pb2 as sdk_dot_core_dot_assets__pb2
from kaikosdk.core import window_pb2 as sdk_dot_core_dot_window__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<sdk/stream/aggregates_direct_exchange_rate_v2/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15sdk/core/assets.proto\x1a\x15sdk/core/window.proto\"\xc4\x01\n.StreamAggregatesDirectExchangeRateV2ResponseV1\x12 \n\x06\x61ssets\x18\x01 \x01(\x0b\x32\x10.kaikosdk.Assets\x12\r\n\x05price\x18\x02 \x01(\x01\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x06window\x18\x04 \x01(\x0b\x32\x10.kaikosdk.Window\x12\x10\n\x08no_trade\x18\x05 \x01(\x08\x42\xdc\x01\n7com.kaiko.sdk.stream.aggregates_direct_exchange_rate_v2P\x01Zngithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_direct_exchange_rate_v2;aggregates_direct_exchange_rate_v2\xaa\x02.KaikoSdk.Stream.AggregatesDirectExchangeRateV2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregates_direct_exchange_rate_v2.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.kaiko.sdk.stream.aggregates_direct_exchange_rate_v2P\001Zngithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_direct_exchange_rate_v2;aggregates_direct_exchange_rate_v2\252\002.KaikoSdk.Stream.AggregatesDirectExchangeRateV2'
  _globals['_STREAMAGGREGATESDIRECTEXCHANGERATEV2RESPONSEV1']._serialized_start=154
  _globals['_STREAMAGGREGATESDIRECTEXCHANGERATEV2RESPONSEV1']._serialized_end=350
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from kaikosdk.stream.aggregated_price_v1 import request_pb2 as sdk_dot_stream_dot_aggregated__price__v1_dot_request__pb2
from kaikosdk.stream.aggregated_price_v1 import response_pb2 as sdk_dot_stream_dot_aggregated__price__v1_dot_response__pb2
from kaikosdk.stream.aggregated_quote_v2 import request_pb2 as sdk_dot_stream_dot_aggregated__quote__v2_dot_request__pb2
from kaikosdk.stream.aggregated_quote_v2 import response_pb2 as sdk_dot_stream_dot_aggregated__quote__v2_dot_response__pb2
from kaikosdk.stream.aggregates_direct_exchange_rate_v2 import request_pb2 as sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_request__pb2
from kaikosdk.stream.aggregates_direct_exchange_rate_v2 import response_pb2 as sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_response__pb2
from kaikosdk.stream.aggregates_ohlcv_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_request__pb2
from kaikosdk.stream.aggregates_ohlcv_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_response__pb2
from kaikosdk.stream.aggregates_spot_exchange_rate_v2 import request_pb2 as sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_request__pb2
from kaikosdk.stream.aggregates_spot_exchange_rate_v2 import response_pb2 as sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_response__pb2
from kaikosdk.stream.aggregates_vwap_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__vwap__v1_dot_request__pb2
from kaikosdk.stream.aggregates_vwap_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__vwap__v1_dot_response__pb2
from kaikosdk.stream.derivatives_instrument_metrics_v1 import request_pb2 as sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_request__pb2
from kaikosdk.stream.derivatives_instrument_metrics_v1 import response_pb2 as sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_response__pb2
from kaikosdk.stream.exotic_indices_v1 import request_pb2 as sdk_dot_stream_dot_exotic__indices__v1_dot_request__pb2
from kaikosdk.stream.exotic_indices_v1 import response_pb2 as sdk_dot_stream_dot_exotic__indices__v1_dot_response__pb2
from kaikosdk.stream.index_forex_rate_v1 import request_pb2 as sdk_dot_stream_dot_index__forex__rate__v1_dot_request__pb2
from kaikosdk.stream.index_forex_rate_v1 import response_pb2 as sdk_dot_stream_dot_index__forex__rate__v1_dot_response__pb2
from kaikosdk.stream.index_multi_assets_v1 import request_pb2 as sdk_dot_stream_dot_index__multi__assets__v1_dot_request__pb2
from kaikosdk.stream.index_multi_assets_v1 import response_pb2 as sdk_dot_stream_dot_index__multi__assets__v1_dot_response__pb2
from kaikosdk.stream.index_v1 import request_pb2 as sdk_dot_stream_dot_index__v1_dot_request__pb2
from kaikosdk.stream.index_v1 import response_pb2 as sdk_dot_stream_dot_index__v1_dot_response__pb2
from kaikosdk.stream.iv_svi_parameters_v1 import request_pb2 as sdk_dot_stream_dot_iv__svi__parameters__v1_dot_request__pb2
from kaikosdk.stream.iv_svi_parameters_v1 import response_pb2 as sdk_dot_stream_dot_iv__svi__parameters__v1_dot_response__pb2
from kaikosdk.stream.market_update_v1 import request_pb2 as sdk_dot_stream_dot_market__update__v1_dot_request__pb2
from kaikosdk.stream.market_update_v1 import response_pb2 as sdk_dot_stream_dot_market__update__v1_dot_response__pb2
from kaikosdk.stream.trades_v1 import request_pb2 as sdk_dot_stream_dot_trades__v1_dot_request__pb2
from kaikosdk.stream.trades_v1 import response_pb2 as sdk_dot_stream_dot_trades__v1_dot_response__pb2


class StreamAggregatedQuoteServiceV2Stub(object):
    """Service for streaming Aggregated Quote V2
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamAggregatedQuoteServiceV2/Subscribe',
                request_serializer=sdk_dot_stream_dot_aggregated__quote__v2_dot_request__pb2.StreamAggregatedQuoteRequestV2.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_aggregated__quote__v2_dot_response__pb2.StreamAggregatedQuoteResponseV2.FromString,
                )


class StreamAggregatedQuoteServiceV2Servicer(object):
    """Service for streaming Aggregated Quote V2
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamAggregatedQuoteServiceV2Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_aggregated__quote__v2_dot_request__pb2.StreamAggregatedQuoteRequestV2.FromString,
                    response_serializer=sdk_dot_stream_dot_aggregated__quote__v2_dot_response__pb2.StreamAggregatedQuoteResponseV2.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamAggregatedQuoteServiceV2', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamAggregatedQuoteServiceV2(object):
    """Service for streaming Aggregated Quote V2
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamAggregatedQuoteServiceV2/Subscribe',
            sdk_dot_stream_dot_aggregated__quote__v2_dot_request__pb2.StreamAggregatedQuoteRequestV2.SerializeToString,
            sdk_dot_stream_dot_aggregated__quote__v2_dot_response__pb2.StreamAggregatedQuoteResponseV2.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamAggregatedPriceServiceV1Stub(object):
    """Service for streaming Aggregated Price V1
    Service is deprecated, use `StreamAggregatedQuoteServiceV1` instead.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamAggregatedPriceServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_aggregated__price__v1_dot_request__pb2.StreamAggregatedPriceRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_aggregated__price__v1_dot_response__pb2.StreamAggregatedPriceResponseV1.FromString,
                )


class StreamAggregatedPriceServiceV1Servicer(object):
    """Service for streaming Aggregated Price V1
    Service is deprecated, use `StreamAggregatedQuoteServiceV1` instead.
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamAggregatedPriceServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_aggregated__price__v1_dot_request__pb2.StreamAggregatedPriceRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_aggregated__price__v1_dot_response__pb2.StreamAggregatedPriceResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamAggregatedPriceServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamAggregatedPriceServiceV1(object):
    """Service for streaming Aggregated Price V1
    Service is deprecated, use `StreamAggregatedQuoteServiceV1` instead.
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamAggregatedPriceServiceV1/Subscribe',
            sdk_dot_stream_dot_aggregated__price__v1_dot_request__pb2.StreamAggregatedPriceRequestV1.SerializeToString,
            sdk_dot_stream_dot_aggregated__price__v1_dot_response__pb2.StreamAggregatedPriceResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamAggregatesOHLCVServiceV1Stub(object):
    """Service for streaming OHLCV V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamAggregatesOHLCVServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_request__pb2.StreamAggregatesOHLCVRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_response__pb2.StreamAggregatesOHLCVResponseV1.FromString,
                )


class StreamAggregatesOHLCVServiceV1Servicer(object):
    """Service for streaming OHLCV V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamAggregatesOHLCVServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_request__pb2.StreamAggregatesOHLCVRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_response__pb2.StreamAggregatesOHLCVResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamAggregatesOHLCVServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamAggregatesOHLCVServiceV1(object):
    """Service for streaming OHLCV V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamAggregatesOHLCVServiceV1/Subscribe',
            sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_request__pb2.StreamAggregatesOHLCVRequestV1.SerializeToString,
            sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_response__pb2.StreamAggregatesOHLCVResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamTradesServiceV1Stub(object):
    """Service for streaming trades V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamTradesServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_trades__v1_dot_request__pb2.StreamTradesRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_trades__v1_dot_response__pb2.StreamTradesResponseV1.FromString,
                )


class StreamTradesServiceV1Servicer(object):
    """Service for streaming trades V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamTradesServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_trades__v1_dot_request__pb2.StreamTradesRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_trades__v1_dot_response__pb2.StreamTradesResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamTradesServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamTradesServiceV1(object):
    """Service for streaming trades V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamTradesServiceV1/Subscribe',
            sdk_dot_stream_dot_trades__v1_dot_request__pb2.StreamTradesRequestV1.SerializeToString,
            sdk_dot_stream_dot_trades__v1_dot_response__pb2.StreamTradesResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamAggregatesVWAPServiceV1Stub(object):
    """Service for streaming VWAP V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamAggregatesVWAPServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_aggregates__vwap__v1_dot_request__pb2.StreamAggregatesVWAPRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_aggregates__vwap__v1_dot_response__pb2.StreamAggregatesVWAPResponseV1.FromString,
                )


class StreamAggregatesVWAPServiceV1Servicer(object):
    """Service for streaming VWAP V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamAggregatesVWAPServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_aggregates__vwap__v1_dot_request__pb2.StreamAggregatesVWAPRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_aggregates__vwap__v1_dot_response__pb2.StreamAggregatesVWAPResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamAggregatesVWAPServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamAggregatesVWAPServiceV1(object):
    """Service for streaming VWAP V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamAggregatesVWAPServiceV1/Subscribe',
            sdk_dot_stream_dot_aggregates__vwap__v1_dot_request__pb2.StreamAggregatesVWAPRequestV1.SerializeToString,
            sdk_dot_stream_dot_aggregates__vwap__v1_dot_response__pb2.StreamAggregatesVWAPResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamIndexServiceV1Stub(object):
    """Service for streaming index V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamIndexServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_index__v1_dot_request__pb2.StreamIndexServiceRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_index__v1_dot_response__pb2.StreamIndexServiceResponseV1.FromString,
                )


class StreamIndexServiceV1Servicer(object):
    """Service for streaming index V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamIndexServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_index__v1_dot_request__pb2.StreamIndexServiceRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_index__v1_dot_response__pb2.StreamIndexServiceResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamIndexServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamIndexServiceV1(object):
    """Service for streaming index V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamIndexServiceV1/Subscribe',
            sdk_dot_stream_dot_index__v1_dot_request__pb2.StreamIndexServiceRequestV1.SerializeToString,
            sdk_dot_stream_dot_index__v1_dot_response__pb2.StreamIndexServiceResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamIndexMultiAssetsServiceV1Stub(object):
    """Service for streaming index multi assets V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamIndexMultiAssetsServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_index__multi__assets__v1_dot_request__pb2.StreamIndexMultiAssetsServiceRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_index__multi__assets__v1_dot_response__pb2.StreamIndexMultiAssetsServiceResponseV1.FromString,
                )


class StreamIndexMultiAssetsServiceV1Servicer(object):
    """Service for streaming index multi assets V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamIndexMultiAssetsServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_index__multi__assets__v1_dot_request__pb2.StreamIndexMultiAssetsServiceRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_index__multi__assets__v1_dot_response__pb2.StreamIndexMultiAssetsServiceResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamIndexMultiAssetsServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamIndexMultiAssetsServiceV1(object):
    """Service for streaming index multi assets V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamIndexMultiAssetsServiceV1/Subscribe',
            sdk_dot_stream_dot_index__multi__assets__v1_dot_request__pb2.StreamIndexMultiAssetsServiceRequestV1.SerializeToString,
            sdk_dot_stream_dot_index__multi__assets__v1_dot_response__pb2.StreamIndexMultiAssetsServiceResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamMarketUpdateServiceV1Stub(object):
    """Service for streaming market update V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamMarketUpdateServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_market__update__v1_dot_request__pb2.StreamMarketUpdateRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_market__update__v1_dot_response__pb2.StreamMarketUpdateResponseV1.FromString,
                )


class StreamMarketUpdateServiceV1Servicer(object):
    """Service for streaming market update V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamMarketUpdateServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_market__update__v1_dot_request__pb2.StreamMarketUpdateRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_market__update__v1_dot_response__pb2.StreamMarketUpdateResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamMarketUpdateServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamMarketUpdateServiceV1(object):
    """Service for streaming market update V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamMarketUpdateServiceV1/Subscribe',
            sdk_dot_stream_dot_market__update__v1_dot_request__pb2.StreamMarketUpdateRequestV1.SerializeToString,
            sdk_dot_stream_dot_market__update__v1_dot_response__pb2.StreamMarketUpdateResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamAggregatesSpotExchangeRateV2ServiceV1Stub(object):
    """Service for streaming Spot exchange rate V2 service V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamAggregatesSpotExchangeRateV2ServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_request__pb2.StreamAggregatesSpotExchangeRateV2RequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_response__pb2.StreamAggregatesSpotExchangeRateV2ResponseV1.FromString,
                )


class StreamAggregatesSpotExchangeRateV2ServiceV1Servicer(object):
    """Service for streaming Spot exchange rate V2 service V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamAggregatesSpotExchangeRateV2ServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_request__pb2.StreamAggregatesSpotExchangeRateV2RequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_response__pb2.StreamAggregatesSpotExchangeRateV2ResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamAggregatesSpotExchangeRateV2ServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamAggregatesSpotExchangeRateV2ServiceV1(object):
    """Service for streaming Spot exchange rate V2 service V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamAggregatesSpotExchangeRateV2ServiceV1/Subscribe',
            sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_request__pb2.StreamAggregatesSpotExchangeRateV2RequestV1.SerializeToString,
            sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_response__pb2.StreamAggregatesSpotExchangeRateV2ResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamAggregatesSpotDirectExchangeRateV2ServiceV1Stub(object):
    """Service for streaming Direct exchange rate V2 service V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamAggregatesSpotDirectExchangeRateV2ServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_request__pb2.StreamAggregatesDirectExchangeRateV2RequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_response__pb2.StreamAggregatesDirectExchangeRateV2ResponseV1.FromString,
                )


class StreamAggregatesSpotDirectExchangeRateV2ServiceV1Servicer(object):
    """Service for streaming Direct exchange rate V2 service V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamAggregatesSpotDirectExchangeRateV2ServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_request__pb2.StreamAggregatesDirectExchangeRateV2RequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_response__pb2.StreamAggregatesDirectExchangeRateV2ResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamAggregatesSpotDirectExchangeRateV2ServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamAggregatesSpotDirectExchangeRateV2ServiceV1(object):
    """Service for streaming Direct exchange rate V2 service V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamAggregatesSpotDirectExchangeRateV2ServiceV1/Subscribe',
            sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_request__pb2.StreamAggregatesDirectExchangeRateV2RequestV1.SerializeToString,
            sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_response__pb2.StreamAggregatesDirectExchangeRateV2ResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamIndexForexRateServiceV1Stub(object):
    """Service for streaming index Forex rate assets V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamIndexForexRateServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_index__forex__rate__v1_dot_request__pb2.StreamIndexForexRateServiceRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_index__forex__rate__v1_dot_response__pb2.StreamIndexForexRateServiceResponseV1.FromString,
                )


class StreamIndexForexRateServiceV1Servicer(object):
    """Service for streaming index Forex rate assets V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamIndexForexRateServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_index__forex__rate__v1_dot_request__pb2.StreamIndexForexRateServiceRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_index__forex__rate__v1_dot_response__pb2.StreamIndexForexRateServiceResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamIndexForexRateServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamIndexForexRateServiceV1(object):
    """Service for streaming index Forex rate assets V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamIndexForexRateServiceV1/Subscribe',
            sdk_dot_stream_dot_index__forex__rate__v1_dot_request__pb2.StreamIndexForexRateServiceRequestV1.SerializeToString,
            sdk_dot_stream_dot_index__forex__rate__v1_dot_response__pb2.StreamIndexForexRateServiceResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamDerivativesInstrumentMetricsServiceV1Stub(object):
    """Service for streaming derivatives instrument metrics V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamDerivativesInstrumentMetricsServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_request__pb2.StreamDerivativesInstrumentMetricsRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_response__pb2.StreamDerivativesInstrumentMetricsResponseV1.FromString,
                )


class StreamDerivativesInstrumentMetricsServiceV1Servicer(object):
    """Service for streaming derivatives instrument metrics V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamDerivativesInstrumentMetricsServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_request__pb2.StreamDerivativesInstrumentMetricsRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_response__pb2.StreamDerivativesInstrumentMetricsResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamDerivativesInstrumentMetricsServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamDerivativesInstrumentMetricsServiceV1(object):
    """Service for streaming derivatives instrument metrics V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamDerivativesInstrumentMetricsServiceV1/Subscribe',
            sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_request__pb2.StreamDerivativesInstrumentMetricsRequestV1.SerializeToString,
            sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_response__pb2.StreamDerivativesInstrumentMetricsResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamIvSviParametersServiceV1Stub(object):
    """Service for streaming IV SVI parameters V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamIvSviParametersServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_iv__svi__parameters__v1_dot_request__pb2.StreamIvSviParametersRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_iv__svi__parameters__v1_dot_response__pb2.StreamIvSviParametersResponseV1.FromString,
                )


class StreamIvSviParametersServiceV1Servicer(object):
    """Service for streaming IV SVI parameters V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamIvSviParametersServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_iv__svi__parameters__v1_dot_request__pb2.StreamIvSviParametersRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_iv__svi__parameters__v1_dot_response__pb2.StreamIvSviParametersResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamIvSviParametersServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamIvSviParametersServiceV1(object):
    """Service for streaming IV SVI parameters V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamIvSviParametersServiceV1/Subscribe',
            sdk_dot_stream_dot_iv__svi__parameters__v1_dot_request__pb2.StreamIvSviParametersRequestV1.SerializeToString,
            sdk_dot_stream_dot_iv__svi__parameters__v1_dot_response__pb2.StreamIvSviParametersResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StreamExoticIndicesServiceV1Stub(object):
    """Service for streaming Exotic Indices V1
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream(
                '/kaikosdk.StreamExoticIndicesServiceV1/Subscribe',
                request_serializer=sdk_dot_stream_dot_exotic__indices__v1_dot_request__pb2.StreamExoticIndicesServiceRequestV1.SerializeToString,
                response_deserializer=sdk_dot_stream_dot_exotic__indices__v1_dot_response__pb2.StreamExoticIndicesServiceResponseV1.FromString,
                )


class StreamExoticIndicesServiceV1Servicer(object):
    """Service for streaming Exotic Indices V1
    """

    def Subscribe(self, request, context):
        """Subscribe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamExoticIndicesServiceV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=sdk_dot_stream_dot_exotic__indices__v1_dot_request__pb2.StreamExoticIndicesServiceRequestV1.FromString,
                    response_serializer=sdk_dot_stream_dot_exotic__indices__v1_dot_response__pb2.StreamExoticIndicesServiceResponseV1.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaikosdk.StreamExoticIndicesServiceV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamExoticIndicesServiceV1(object):
    """Service for streaming Exotic Indices V1
    """

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaikosdk.StreamExoticIndicesServiceV1/Subscribe',
            sdk_dot_stream_dot_exotic__indices__v1_dot_request__pb2.StreamExoticIndicesServiceRequestV1.SerializeToString,
            sdk_dot_stream_dot_exotic__indices__v1_dot_response__pb2.StreamExoticIndicesServiceResponseV1.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_vwap_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,sdk/stream/aggregates_vwap_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc1\x01\n\x1eStreamAggregatesVWAPResponseV1\x12\x11\n\taggregate\x18\x01 \x01(\t\x12\r\n\x05\x63lass\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12\x13\n\x0bsequence_id\x18\x05 \x01(\t\x12\r\n\x05price\x18\x06 \x01(\x01\x12,\n\x08ts_event\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03uid\x18\x08 \x01(\tB\x9e\x01\n\'com.kaiko.sdk.stream.aggregates_vwap_v1P\x01ZNgithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_vwap_v1;aggregates_vwap_v1\xaa\x02 KaikoSdk.Stream.AggregatesVWAPV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregates_vwap_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.kaiko.sdk.stream.aggregates_vwap_v1P\001ZNgithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_vwap_v1;aggregates_vwap_v1\252\002 KaikoSdk.Stream.AggregatesVWAPV1'
  _globals['_STREAMAGGREGATESVWAPRESPONSEV1']._serialized_start=92
  _globals['_STREAMAGGREGATESVWAPRESPONSEV1']._serialized_end=285
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/derivatives_instrument_metrics_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.stream.derivatives_instrument_metrics_v1 import commodity_kind_pb2 as sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_commodity__kind__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;sdk/stream/derivatives_instrument_metrics_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x41sdk/stream/derivatives_instrument_metrics_v1/commodity_kind.proto\"\xa8\x02\n,StreamDerivativesInstrumentMetricsResponseV1\x12\r\n\x05value\x18\x01 \x01(\t\x12\x15\n\rlegacy_symbol\x18\x02 \x01(\t\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x11\n\tcommodity\x18\x04 \x01(\t\x12L\n\x0e\x63ommodity_kind\x18\x05 \x01(\x0e\x32\x34.kaikosdk.StreamDerivativesInstrumentCommodityKindV1\x12\x31\n\rts_collection\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08ts_event\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xd9\x01\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\x01Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\xaa\x02.KaikoSdk.Stream.DerivativesInstrumentMetricsV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.derivatives_instrument_metrics_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\001Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\252\002.KaikoSdk.Stream.DerivativesInstrumentMetricsV1'
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSRESPONSEV1']._serialized_start=174
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSRESPONSEV1']._serialized_end=470
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_direct_exchange_rate_v2/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from kaikosdk.core import assets_pb2 as sdk_dot_core_dot_assets__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;sdk/stream/aggregates_direct_exchange_rate_v2/request.proto\x12\x08kaikosdk\x1a\x1egoogle/protobuf/duration.proto\x1a\x15sdk/core/assets.proto\"\xe7\x01\n-StreamAggregatesDirectExchangeRateV2RequestV1\x12 \n\x06\x61ssets\x18\x01 \x01(\x0b\x32\x10.kaikosdk.Assets\x12)\n\x06window\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11include_exchanges\x18\x03 \x03(\t\x12\x19\n\x11\x65xclude_exchanges\x18\x04 \x03(\t\x12\x33\n\x10update_frequency\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\xdc\x01\n7com.kaiko.sdk.stream.aggregates_direct_exchange_rate_v2P\x01Zngithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_direct_exchange_rate_v2;aggregates_direct_exchange_rate_v2\xaa\x02.KaikoSdk.Stream.AggregatesDirectExchangeRateV2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregates_direct_exchange_rate_v2.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.kaiko.sdk.stream.aggregates_direct_exchange_rate_v2P\001Zngithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_direct_exchange_rate_v2;aggregates_direct_exchange_rate_v2\252\002.KaikoSdk.Stream.AggregatesDirectExchangeRateV2'
  _globals['_STREAMAGGREGATESDIRECTEXCHANGERATEV2REQUESTV1']._serialized_start=129
  _globals['_STREAMAGGREGATESDIRECTEXCHANGERATEV2REQUESTV1']._serialized_end=360
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/exotic_indices_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*sdk/stream/exotic_indices_v1/request.proto\x12\x08kaikosdk\x1a\x1csdk/core/data_interval.proto\x1a#sdk/stream/index_v1/commodity.proto\"\x98\x01\n#StreamExoticIndicesServiceRequestV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x33\n\x0b\x63ommodities\x18\x02 \x03(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataIntervalB\x9a\x01\n&com.kaiko.sdk.stream.exotic_indices_v1P\x01ZLgithub.com/kaikodata/kaiko-go-sdk/stream/exotic_indices_v1;exotic_indices_v1\xaa\x02\x1fKaikoSdk.Stream.ExoticIndicesV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.exotic_indices_v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.kaiko.sdk.stream.exotic_indices_v1P\001ZLgithub.com/kaikodata/kaiko-go-sdk/stream/exotic_indices_v1;exotic_indices_v1\252\002\037KaikoSdk.Stream.ExoticIndicesV1'
  _globals['_STREAMEXOTICINDICESSERVICEREQUESTV1']._serialized_start=124
  _globals['_STREAMEXOTICINDICESSERVICEREQUESTV1']._serialized_end=276
# @@protoc_insertion_point(module_scope)
